@@ -77,7 +77,10 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
                                          list(df_logs_combined["EVENT_TIME"])]
 
     df_logs_combined['EVENT_TIME_DATETIME'] = pd.Series(map(converter, df_logs_combined["EVENT_TIME"]))
-    df_logs_combined['Date'] = df_logs_combined['EVENT_TIME_DATETIME'].dt.date
+    try:
+        df_logs_combined['Date'] = df_logs_combined['EVENT_TIME_DATETIME'].dt.date
+    except AttributeError:
+        raise Exception("AttributeError (phone lock): " + intermediate_participant_path + date_in_study + df_logs_combined)
 
     return df_logs_combined
 
