@@ -60,11 +60,13 @@ def execute(intermediate_participant_path, output_dir_path, rerun=False):
         info_dict = create_json(intermediate_participant_path, output_dir_path)
     else:
         # Load existing json file
-        if os.path.exists(information_dict_path):
-            with open(information_dict_path) as f:
-                info_dict = json.load(f)
-        else: # Create if info file doesn't exist
-            info_dict = create_json(intermediate_participant_path, output_dir_path)
+        # if os.path.exists(information_dict_path):
+        #     with open(information_dict_path) as f:
+        #         info_dict = json.load(f)
+        # else: # Create if info file doesn't exist
+        #     info_dict = create_json(intermediate_participant_path, output_dir_path)
+        with open(information_dict_path) as f:
+            info_dict = json.load(f)
 
     return info_dict
 
